Module lifecycle

Module lifecycle 

Nested message and enum types in Lifecycle.

Modules

rule
Nested message and enum types in Rule.

Structs

Rule
A lifecycle Rule, combining an action to take on an object and a condition which will trigger that action.