pub struct ErrorResponseItem {
pub domain: String,
pub location: Option<String>,
pub location_type: Option<String>,
pub message: String,
pub reason: String,
}Fields
domain: StringThe scope of the error. Example values include: global and push.
location: Option<String>The specific item within the locationType that caused the error. For example, if you
specify an invalid value for a parameter, the location will be the name of the parameter.
Example values include: Authorization, project, and projection.
location_type: Option<String>The location or part of the request that caused the error. Use with location to pinpoint
the error. For example, if you specify an invalid value for a parameter, the locationType
will be parameter and the location will be the name of the parameter.
Example values include header and parameter.
message: StringDescription of the error.
Example values include Invalid argument, Login required, and
Required parameter: project.
reason: StringExample values include invalid, invalidParameter, and required.